using Unicode

"""Create NFKC forms of code points with diaeresis.

$(SIGNATURES)
"""
function normalizediaresis()
    combos = [
        "ΐ",
        "ῒ",
        "ῗ",
        "ΰ",
        "ῢ",
        "ῧ"
    ]
    map(s -> Unicode.normalize(s, :NFKC), combos)
end

"""Collect a normalized set of all codepoints
with accent.

$(SIGNATURES)
"""
function normalizeaccentcombos()
    combos = [
        "'ά'  => 'α'",
        "'ὰ' => 'α'",
        "'ᾶ' => 'α'",
        "'ᾴ' => 'ᾳ'",
        "'ᾲ' => 'ᾳ'",
        "'ᾷ' => 'ᾳ'",
        "'ἄ' => 'ἀ'",
        "'ἂ' => 'ἀ'",
        "'ἆ' => 'ἀ'",
        "'ᾄ' => 'ᾀ'",
        "'ᾂ' => 'ᾀ'",
        "'ᾆ' => 'ᾀ'",
        "'ἅ' => 'ἁ'",
        "'ἃ' => 'ἁ'",
        "'ἇ' => 'ἁ'",
        "'ᾅ' => 'ᾁ'",
        "'ᾃ' => 'ᾁ'",
        "'ᾇ' => 'ᾁ'",
        #= ========= =#

        "'ή'  => 'η'",
        "'ὴ' => 'η'",
        "'ῆ' => 'η'",
        
        "'ῄ' => 'ῃ'",
        "'ῂ' => 'ῃ'",
        "'ῇ' => 'ῃ'",

        "'ἤ' => 'ἠ'",
        "'ἢ' => 'ἠ'",
        "'ἦ' => 'ἠ'",

        "'ᾔ' => 'ᾐ'",
        "'ᾒ' => 'ᾐ'",
        "'ᾖ' => 'ᾐ'",

        "'ἥ' => 'ἡ'",
        "'ἣ' => 'ἡ'",
        "'ἧ' => 'ἡ'",

        "'ᾕ' => 'ᾑ'",
        "'ᾓ' => 'ᾑ'",
        "'ᾗ' => 'ᾑ'",

        #= ========= =#

        "'ώ'  => 'ω'",
        "'ὼ' => 'ω'",
        "'ῶ' => 'ω'",
        
        "'ῴ' => 'ῳ'",
        "'ῲ' => 'ῳ'",
        "'ῷ' => 'ῳ'",

        "'ὤ' => 'ὠ'",
        "'ὢ' => 'ὠ'",
        "'ὦ' => 'ὠ'",

        "'ᾤ' => 'ᾠ'",
        "'ᾢ' => 'ᾠ'",
        "'ᾦ' => 'ᾠ'",

        "'ὥ' => 'ὡ'",
        "'ὣ' => 'ὡ'",
        "'ὧ' => 'ὡ'",

        "'ᾥ' => 'ᾡ'",
        "'ᾓ' => 'ᾡ'",
        "'ᾗ' => 'ᾡ'",

        #= ========= =#
        # ADD IOTA
        "'ί' => 'ι'",
        "'ὶ' => 'ι'",
        "'ῖ' => 'ι'",

        "'ἴ' => 'ἰ'",
        "'ἲ' => 'ἰ'",
        "'ἶ' => 'ἱ'",

        "'ἵ' => 'ἱ'",
        "'ἳ' => 'ἱ'",
        "'ἷ' => 'ἱ'",

        "'ΐ' => 'ϊ'",
        "'ῒ' => 'ϊ'",
        "'ῗ' => 'ϊ'",

        # ADD UPSILON
        "'ύ' => 'υ'",
        "'ὺ' => 'υ'",
        "'ῦ' => 'υ'",

        "'ἴ' => 'ὐ'",
        "'ὒ' => 'ὐ'",
        "'ὗ' => 'ὐ'",

        "'ἵ' => 'ὑ'",
        "'ὓ' => 'ὑ'",
        "'ὗ' => 'ὑ'",

        "'ΰ' => 'ϋ'",
        "'ῢ' => 'ϋ'",
        "'ῧ' => 'ϋ'",

        #= ========= =#

        "'έ' => 'ε'",
        "'ὲ' => 'ε'",

        "'ἔ' => 'ἐ'",
        "'ἒ' => 'ἐ'",

        "'ἕ' => 'ἐ'",
        "'ἓ' => 'ἑ'",

        "'ό' => 'ο'",
        "'ὸ' => 'ο'",

        "'ὄ' => 'ὀ'",
        "'ὂ' => 'ὀ'",

        "'ὅ' => 'ὁ'",
        "'ὃ' => 'ὁ'",

        
  
    ]
    map(s -> Unicode.normalize(s, :NFKC), combos)
end